==> XSV-2.5.tar.gz: XSV-2.5/XSV/commandLine.py <==
"""Drive XSV from command line"""

__version__="$Revision: 1.6 $ of $Date: 2003/03/30 20:05:46 $"
# $Id: commandLine.py,v 1.6 2003/03/30 20:05:46 ht Exp $

import sys

_usageString="Usage: [-ktwilDN] [-T type] [-E elt] [-r [-r [-r]] [ind|alt]] [-s stylesheet] [-o outputFile] [-p profileOut] file [schema1 schema2 . . .]\n"

def parseAndRun(argl):
  k=0
  dw=1
  timing=0
  style=None
  outfile=None
  reflect=0
  reflect2=0
  independent=0
  proFile=None
  scanForLocs=0
  useDTD=0
  topType=None
  topElt=None
  derefNSNs=1
  control=2
  while argl:
    if argl[0]=='-k':
      k=1
    elif argl[0]=='-s':
      style=argl[1]
      argl=argl[1:]
    elif argl[0]=='-o':
      outfile=argl[1]
      argl=argl[1:]
    elif argl[0]=='-p':
      proFile=argl[1]
      argl=argl[1:]
    elif argl[0]=='-T':
      topType=argl[1]
      argl=argl[1:]
    elif argl[0]=='-E':
      topElt=argl[1]
      argl=argl[1:]
    elif argl[0]=='-w':
      dw=0
    elif argl[0]=='-l':
      scanForLocs=1
    elif argl[0]=='-D':
      useDTD=1
    elif argl[0]=='-N':
      derefNSNs=0
    elif argl[0]=='-t':
      timing=1
    elif argl[0]=='-r':
      while (len(argl)>1 and argl[1]=='-r'):
        argl=argl[1:]
        control=control-1
      if len(argl)>1:
        if argl[1]=='alt':
          reflect=2
          argl=argl[2:]
          continue
        elif argl[1]=='ind':
          reflect=1
          argl=argl[2:]
          continue
      reflect=1
    elif argl[0]=='-R':
      reflect2=1
    elif argl[0]=='-i':
      independent=1
    elif argl[0][0]=='-':
      sys.stderr.write(_usageString)
      sys.exit(-1)
    else:
      break
    argl=argl[1:]

  from XSV.driver import runitAndShow, SchemaValidationError
  if argl:
    if proFile:
      import profile
      res=profile.run("""runitAndShow(argl[0],argl[1:],k,
                         style,None,outfile,dw,timing,reflect,independent,
                         reflect2,scanForLocs,useDTD,topType,topElt,
                         derefNSNs,control)""",
                      proFile)
    else:
      res=runitAndShow(argl[0],argl[1:],
                       k,style,None,outfile,dw,timing,reflect,
                       independent,reflect2,scanForLocs,useDTD,topType,
                       topElt,derefNSNs,control)
  else:
    res=runitAndShow(None,[],k,
                         style,None,outfile,dw,timing,reflect,independent,
                         reflect2,scanForLocs,useDTD,topType,topElt,derefNSNs,
                     control)

  if res is not None:
    raise SchemaValidationError,res

if __name__=='__main__':
  parseAndRun(sys.argv[1:])

# $Log: commandLine.py,v $
# Revision 1.6  2003/03/30 20:05:46  ht
# give command-line control over amount of schema material reflected
#
# Revision 1.5  2003/02/14 09:36:25  ht
# add -N switch to supress derefing namespace names
#
# Revision 1.4  2002/10/09 09:47:11  ht
# change 'rel' to 'alt' (which is what it is, after all)
#
# Revision 1.3  2002/10/08 21:10:05  ht
# minor
#
# Revision 1.2  2002/09/01 19:23:23  ht
# allow for command line spec. of type or elt
#
# Revision 1.1  2002/06/28 09:39:17  ht
# XSV as package: top level
#

==> XSV-2.7.tar.gz: XSV-2.7/XSV/commandLine.py <==
"""Drive XSV from command line"""

__version__="$Revision: 1.8 $ of $Date: 2004/04/01 12:52:39 $"
# $Id: commandLine.py,v 1.8 2004/04/01 12:52:39 ht Exp $

import sys

_usageString="Usage: [-ktwilDNe] [-u baseURI] [-T type] [-E elt] [-r [-r [-r]] [ind|alt]] [-s stylesheet] [-o outputFile] [-p profileOut] file [schema1 schema2 . . .]\n"

def parseAndRun(argl):
  k=0
  dw=1
  timing=0
  style=None
  outfile=None
  reflect=0
  reflect2=0
  independent=0
  proFile=None
  scanForLocs=0
  useDTD=0
  topType=None
  topElt=None
  derefNSNs=1
  control=2
  baseURI=None
  preserveRedirect=0
  while argl:
    if argl[0]=='-k':
      k=1
    elif argl[0]=='-s':
      style=argl[1]
      argl=argl[1:]
    elif argl[0]=='-u':
      baseURI=argl[1]
      argl=argl[1:]
    elif argl[0]=='-o':
      outfile=argl[1]
      argl=argl[1:]
    elif argl[0]=='-p':
      proFile=argl[1]
      argl=argl[1:]
    elif argl[0]=='-T':
      topType=argl[1]
      argl=argl[1:]
    elif argl[0]=='-E':
      topElt=argl[1]
      argl=argl[1:]
    elif argl[0]=='-w':
      dw=0
    elif argl[0]=='-l':
      scanForLocs=1
    elif argl[0]=='-D':
      useDTD=1
    elif argl[0]=='-N':
      derefNSNs=0
    elif argl[0]=='-t':
      timing=1
    elif argl[0]=='-r':
      while (len(argl)>1 and argl[1]=='-r'):
        argl=argl[1:]
        control=control-1
      if len(argl)>1:
        if argl[1]=='alt':
          reflect=2
          argl=argl[2:]
          continue
        elif argl[1]=='ind':
          reflect=1
          argl=argl[2:]
          continue
      reflect=1
    elif argl[0]=='-R':
      reflect2=1
    elif argl[0]=='-i':
      independent=1
    elif argl[0]=='-e':
      preserveRedirect=1
    elif argl[0][0]=='-':
      sys.stderr.write(_usageString)
      sys.exit(-1)
    else:
      break
    argl=argl[1:]

  from XSV.driver import runitAndShow, SchemaValidationError
  if argl:
    if proFile:
      import profile
      res=profile.run("""runitAndShow(argl[0],argl[1:],k,
                         style,None,outfile,dw,timing,reflect,independent,
                         reflect2,scanForLocs,useDTD,topType,topElt,
                         derefNSNs,control,baseURI,preserveRedirect)""",
                      proFile)
    else:
      res=runitAndShow(argl[0],argl[1:],
                       k,style,None,outfile,dw,timing,reflect,
                       independent,reflect2,scanForLocs,useDTD,topType,
                       topElt,derefNSNs,control,baseURI,preserveRedirect)
  else:
    res=runitAndShow(None,[],k,
                     style,None,outfile,dw,timing,reflect,independent,
                     reflect2,scanForLocs,useDTD,topType,topElt,derefNSNs,
                     control,baseURI,preserveRedirect)

  if res is not None:
    raise SchemaValidationError,res

if __name__=='__main__':
  parseAndRun(sys.argv[1:])

# $Log: commandLine.py,v $
# Revision 1.8  2004/04/01 12:52:39  ht
# add -e flag for preserving captured stderr
#
# Revision 1.7  2003/09/01 15:32:33  ht
# add baseURI command line arg
#
# Revision 1.6  2003/03/30 20:05:46  ht
# give command-line control over amount of schema material reflected
#
# Revision 1.5  2003/02/14 09:36:25  ht
# add -N switch to supress derefing namespace names
#
# Revision 1.4  2002/10/09 09:47:11  ht
# change 'rel' to 'alt' (which is what it is, after all)
#
# Revision 1.3  2002/10/08 21:10:05  ht
# minor
#
# Revision 1.2  2002/09/01 19:23:23  ht
# allow for command line spec. of type or elt
#
# Revision 1.1  2002/06/28 09:39:17  ht
# XSV as package: top level
#
